Stan Math Library: stan/math/prim/mat/fun/log_determinant_ldlt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log_determinant_ldlt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_LOG_DETERMINANT_LDLT_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_LOG_DETERMINANT_LDLT_HPP
3
4 #include <stan/math/prim/mat/fun/LDLT_factor.hpp>
5
6 namespace stan {
7 namespace math {
8
9 // Returns log(abs(det(A))) given a LDLT_factor of A
10 template<int R, int C, typename T>
11 inline T
12 log_determinant_ldlt(stan::math::LDLT_factor<T, R, C> &A) {
13 return A.log_abs_det();
14 }
15
16 }
17 }
18 #endif
stan
Definition: log_sum_exp.hpp:8
LDLT_factor.hpp
stan::math::LDLT_factor< T, R, C >::log_abs_det
T log_abs_det() const
Definition: LDLT_factor.hpp:93
stan::math::LDLT_factor< T, R, C >
LDLT_factor is a thin wrapper on Eigen::LDLT to allow for reusing factorizations and efficient autodi...
Definition: LDLT_factor.hpp:58
stan::math::log_determinant_ldlt
T log_determinant_ldlt(stan::math::LDLT_factor< T, R, C > &A)
Definition: log_determinant_ldlt.hpp:12

[ Stan Home Page ] © 2011–2016, Stan Development Team.